Consumer

Struct Consumer 

pub struct Consumer<S> { /* private fields */ }
The consumer half. Single consumer, so it does not implement Clone.

Implementations

Source

impl<S: Store> Consumer<S>

pub fn reserve(&self) -> Result<Option<Reserved<S>>, S::Error>

Reserve the oldest unreserved item, or None if there is nothing to deliver. Ack or nack the returned Reserved to finish with it.